Changes
-------

1.1 (2023-03-11)
------------------

add new pushsafer parameter answer options, answer force, confirm

1.0 (2021-10-25)
------------------

Fix bugs and completely rewrite.

0.4 (2018-08-19)
~~~~~~~~~~~~~~~~

add new pushsafer parameter priority, retry, expire, answer

0.3 (2017-11-28)
~~~~~~~~~~~~~~~~

ignore verifying the SSL certficate (trust self signed certificates)

0.2 (2017-02-12)
~~~~~~~~~~~~~~~~

Add new parameters (url, url title, time2live, image 1-3), minor bugfixes

0.1 (2016-09-13)
~~~~~~~~~~~~~~~~

Initial Release
